@@ -4,6 +4,7 @@ from pathlib import Path
 import json
 import bson
 from Crypto.Cipher import AES
+from collections.abc import Iterable
 
 
 def get_target_path(obj: Object, output_dir: Path, container_dir: Path) -> Path | None:
@@ -16,6 +17,13 @@ def get_target_path(obj: Object, output_dir: Path, container_dir: Path) -> Path
         return output_dir / container_dir / obj.name
 
 
+def check_pattern_match(test_str: str, patterns: Iterable[str]) -> bool:
+    for pattern in patterns:
+        if pattern in test_str:
+            return True
+    return False
+
+
 def write_bytes(data: bytes, path: Path) -> None:
     path.parent.mkdir(parents=True, exist_ok=True)
     with open(path, "wb") as f:
@@ -60,11 +68,7 @@ def decrypt_textasset(stream: bytes, start_index: int = 128) -> bytes:
     return unpad(decrypted)
 
 
-def export(obj: Object, output_dir: Path, container_dir: Path) -> None:
-    target_path = get_target_path(obj, output_dir, container_dir)
-    if not target_path:
-        return
-
+def export(obj: Object, target_path: Path) -> None:
     match obj:
         case Sprite() | Texture2D():
             if (img := obj.image).width > 0:
@@ -97,12 +101,15 @@ def export(obj: Object, output_dir: Path, container_dir: Path) -> None:
             write_object(tree, target_path)
 
 
-def convert_from_env(env: Environment, output_dir: Path):
+def convert_from_env(env: Environment, output_dir: Path, path_patterns: Iterable[str] | None, show_logs: bool):
     for object in env.objects:
         if object.type.name in {"Sprite", "Texture2D", "TextAsset", "AudioClip", "MonoBehaviour"}:
             resource = object.read()
             if isinstance(resource, Object):
                 container_dir = Path(resource.container).parent if resource.container else Path(env.path)
-                export(resource, output_dir, container_dir)
-        else:
+                target_path = get_target_path(resource, output_dir, container_dir)
+                if target_path:
+                    if (not path_patterns) or check_pattern_match(target_path.as_posix(), path_patterns):
+                        export(resource, target_path)
+        elif show_logs:
             print(f"{object.type.name} object at {env.path} was not processed")
\ No newline at end of file
